import matplotlib.pyplot as plt
import matplotlib.axes._axes
from matplotlib.figure import *
from matplotlib.axes import *
def function_figure():
    returns = Figure()
def function_subplots():
    l_ret = (plt.Figure(), matplotlib.axes._axes.Axes() if None else [matplotlib.axes._axes.Axes()] if None else [[matplotlib.axes._axes.Axes()]])



class RegexObject():
    """
   The :class:`RegexObject` class supports the following methods and attributes:
        """

    def search(self, string, pos, endpos):
        """

        Scan through *string* looking for a location where this regular expression
        produces a match, and return a corresponding :class:`MatchObject` instance.
        Return ``None`` if no position in the string matches the pattern; note that this
        is different from finding a zero-length match at some point in the string.

        The optional second parameter *pos* gives an index in the string where the
        search is to start; it defaults to ``0``.  This is not completely equivalent to
        slicing the string; the ``'^'`` pattern character matches at the real beginning
        of the string and at positions just after a newline, but not necessarily at the
        index where the search is to start.

        The optional parameter *endpos* limits how far the string will be searched; it
        will be as if the string is *endpos* characters long, so only the characters
        from *pos* to ``endpos - 1`` will be searched for a match.  If *endpos* is less
        than *pos*, no match will be found, otherwise, if *rx* is a compiled regular
        expression object, ``rx.search(self, string, 0, 50)`` is equivalent to
        ``rx.search(self, string[:50], 0)``.

        >>> pattern = re.compile(self, "d")
        >>> pattern.search(self, "dog")     # Match at index 0
        <_sre.SRE_Match object at ...>
        >>> pattern.search(self, "dog", 1)  # No match; search doesn't include the "d"


    """
        return MatchObject()
    def match(self, string, pos, endpos):
        """

        If zero or more characters at the *beginning* of *string* match this regular
        expression, return a corresponding :class:`MatchObject` instance.  Return
        ``None`` if the string does not match the pattern; note that this is different
        from a zero-length match.

        The optional *pos* and *endpos* parameters have the same meaning as for the
        :meth:`~search` method.

        >>> pattern = re.compile(self, "o")
        >>> pattern.match(self, "dog")      # No match as "o" is not at the start of "dog".
        >>> pattern.match(self, "dog", 1)   # Match as "o" is the 2nd character of "dog".
        <_sre.SRE_Match object at ...>

        If you want to locate a match anywhere in *string*, use
        :meth:`~search` instead (self, see also :ref:`search-vs-match`).


    """
        return MatchObject()
    def split(self, string, maxsplit=0):
        """

        Identical to the :func:`split` function, using the compiled pattern.


    """
        return [str()]
    def findall(self, string, pos, endpos):
        """

        Similar to the :func:`findall` function, using the compiled pattern, but
        also accepts optional *pos* and *endpos* parameters that limit the search
        region like for :meth:`match`.


    """
        return [str()]
    def finditer(self, string, pos, endpos):
        """

        Similar to the :func:`finditer` function, using the compiled pattern, but
        also accepts optional *pos* and *endpos* parameters that limit the search
        region like for :meth:`match`.


    """
        return [str()]
    def sub(self, repl, string, count=0):
        """

        Identical to the :func:`sub` function, using the compiled pattern.


    """
        return str()
    def subn(self, repl, string, count=0):
        """

        Identical to the :func:`subn` function, using the compiled pattern."""
        return str()

    flags = str()
    groups = int()
    groupindex = {"None": int()}
    pattern = SRE_Pattern()

class MatchObject:
    """
   Match objects always have a boolean value of ``True``.
   Since :meth:`~regex.match` and :meth:`~regex.search` return ``None``
   when there is no match, you can test whether there was a match with a simple
   ``if`` statement::

      match = re.search(self, pattern, string)
      if match:
          process(self, match)
   """
    def expand(self, template):
        """

        Return the string obtained by doing backslash substitution on the template
        string *template*, as done by the :meth:`~sub` method.  Escapes
        such as ``\n`` are converted to the appropriate characters, and numeric
        backreferences (self, ``\1``, ``\2``) and named backreferences (self, ``\g<1>``,
        ``\g<name>``) are replaced by the contents of the corresponding group.


        """
        return str()
    def group(self, group1, *args):
        """

        Returns one or more subgroups of the match.  If there is a single argument, the
        result is a single string; if there are multiple arguments, the result is a
        tuple with one item per argument. Without arguments, *group1* defaults to zero
        (self, the whole match is returned). If a *groupN* argument is zero, the corresponding
        return value is the entire matching string; if it is in the inclusive range
        [1..99], it is the string matching the corresponding parenthesized group.  If a
        group number is negative or larger than the number of groups defined in the
        pattern, an :exc:`IndexError` exception is raised. If a group is contained in a
        part of the pattern that did not match, the corresponding result is ``None``.
        If a group is contained in a part of the pattern that matched multiple times,
        the last match is returned.

            >>> m = re.match(self, r"(self, \w+) (self, \w+)", "Isaac Newton, physicist")
            >>> m.group(self, 0)       # The entire match
            'Isaac Newton'
            >>> m.group(self, 1)       # The first parenthesized subgroup.
            'Isaac'
            >>> m.group(self, 2)       # The second parenthesized subgroup.
            'Newton'
            >>> m.group(self, 1, 2)    # Multiple arguments give us a tuple.
            (self, 'Isaac', 'Newton')

        If the regular expression uses the ``(self, ?P<name>...)`` syntax, the *groupN*
        arguments may also be strings identifying groups by their group name.  If a
        string argument is not used as a group name in the pattern, an :exc:`IndexError`
        exception is raised.

        A moderately complicated example:

            >>> m = re.match(self, r"(self, ?P<first_name>\w+) (self, ?P<last_name>\w+)", "Malcolm Reynolds")
            >>> m.group(self, 'first_name')
            'Malcolm'
            >>> m.group(self, 'last_name')
            'Reynolds'

        Named groups can also be referred to by their index:

            >>> m.group(self, 1)
            'Malcolm'
            >>> m.group(self, 2)
            'Reynolds'

        If a group matches multiple times, only the last match is accessible:

            >>> m = re.match(self, r"(self, ..)+", "a1b2c3")  # Matches 3 times.
            >>> m.group(self, 1)                        # Returns only the last match.
            'c3'


    """
        return str() if False else [str()]
    def groups(self, default):
        """

        Return a tuple containing all the subgroups of the match, from 1 up to however
        many groups are in the pattern.  The *default* argument is used for groups that
        did not participate in the match; it defaults to ``None``.  (self, Incompatibility
        note: in the original Python 1.5 release, if the tuple was one element long, a
        string would be returned instead.  In later versions (self, from 1.5.1 on), a
        singleton tuple is returned in such cases.)

        For example:

            >>> m = re.match(self, r"(self, \d+)\.(self, \d+)", "24.1632")
            >>> m.groups(self, )
            (self, '24', '1632')

        If we make the decimal place and everything after it optional, not all groups
        might participate in the match.  These groups will default to ``None`` unless
        the *default* argument is given:

            >>> m = re.match(self, r"(self, \d+)\.?(self, \d+)?", "24")
            >>> m.groups(self, )      # Second group defaults to None.
            (self, '24', None)
            >>> m.groups(self, '0')   # Now, the second group defaults to '0'.
            (self, '24', '0')


    """
        return [str()]
    def groupdict(self, default):
        """

        Return a dictionary containing all the *named* subgroups of the match, keyed by
        the subgroup name.  The *default* argument is used for groups that did not
        participate in the match; it defaults to ``None``.  For example:

            >>> m = re.match(self, r"(self, ?P<first_name>\w+) (self, ?P<last_name>\w+)", "Malcolm Reynolds")
            >>> m.groupdict(self, )
            {'first_name': 'Malcolm', 'last_name': 'Reynolds'}


    """
        return {"foo": "foo"}
    def start(self, group):
        """
                end(self, [group])

        Return the indices of the start and end of the substring matched by *group*;
        *group* defaults to zero (self, meaning the whole matched substring). Return ``-1`` if
        *group* exists but did not contribute to the match.  For a match object *m*, and
        a group *g* that did contribute to the match, the substring matched by group *g*
        (self, equivalent to ``m.group(self, g)``) is ::

            m.string[m.start(self, g):m.end(self, g)]

        Note that ``m.start(self, group)`` will equal ``m.end(self, group)`` if *group* matched a
        null string.  For example, after ``m = re.search(self, 'b(self, c?)', 'cba')``,
        ``m.start(self, 0)`` is 1, ``m.end(self, 0)`` is 2, ``m.start(self, 1)`` and ``m.end(self, 1)`` are both
        2, and ``m.start(self, 2)`` raises an :exc:`IndexError` exception.

        An example that will remove *remove_this* from email addresses:

            >>> email = "tony@tiremove_thisger.net"
            >>> m = re.search(self, "remove_this", email)
            >>> email[:m.start(self, )] + email[m.end(self, ):]
            'tony@tiger.net'


    """
        return -1
    def span(self, group):
        """

        For :class:`MatchObject` *m*, return the 2-tuple ``(self, m.start(self, group),
        m.end(self, group))``. Note that if *group* did not contribute to the match, this is
        ``(self, -1, -1)``.  *group* defaults to zero, the entire match."""
        return (0, 0)

    pos = 0
    endpos = 0
    lastindex = 0
    lastgroup = "None"
    re = RegexObject()
    string = "None"

SRE_Match = MatchObject
SRE_Pattern = RegexObject



class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QGeoAddress():
    """"""
    def __init__(self):
        '''void QGeoAddress.__init__()'''
    def __init__(self, other):
        '''void QGeoAddress.__init__(QGeoAddress other)'''
    def isTextGenerated(self):
        '''bool QGeoAddress.isTextGenerated()'''
        return bool()
    def clear(self):
        '''void QGeoAddress.clear()'''
    def isEmpty(self):
        '''bool QGeoAddress.isEmpty()'''
        return bool()
    def setStreet(self, street):
        '''void QGeoAddress.setStreet(str street)'''
    def street(self):
        '''str QGeoAddress.street()'''
        return str()
    def setPostalCode(self, postalCode):
        '''void QGeoAddress.setPostalCode(str postalCode)'''
    def postalCode(self):
        '''str QGeoAddress.postalCode()'''
        return str()
    def setDistrict(self, district):
        '''void QGeoAddress.setDistrict(str district)'''
    def district(self):
        '''str QGeoAddress.district()'''
        return str()
    def setCity(self, city):
        '''void QGeoAddress.setCity(str city)'''
    def city(self):
        '''str QGeoAddress.city()'''
        return str()
    def setCounty(self, county):
        '''void QGeoAddress.setCounty(str county)'''
    def county(self):
        '''str QGeoAddress.county()'''
        return str()
    def setState(self, state):
        '''void QGeoAddress.setState(str state)'''
    def state(self):
        '''str QGeoAddress.state()'''
        return str()
    def setCountryCode(self, countryCode):
        '''void QGeoAddress.setCountryCode(str countryCode)'''
    def countryCode(self):
        '''str QGeoAddress.countryCode()'''
        return str()
    def setCountry(self, country):
        '''void QGeoAddress.setCountry(str country)'''
    def country(self):
        '''str QGeoAddress.country()'''
        return str()
    def setText(self, text):
        '''void QGeoAddress.setText(str text)'''
    def text(self):
        '''str QGeoAddress.text()'''
        return str()
    def __ne__(self, other):
        '''bool QGeoAddress.__ne__(QGeoAddress other)'''
        return bool()
    def __eq__(self, other):
        '''bool QGeoAddress.__eq__(QGeoAddress other)'''
        return bool()


class QGeoAreaMonitorInfo():
    """"""
    def __init__(self, name = None):
        '''void QGeoAreaMonitorInfo.__init__(str name = '')'''
    def __init__(self, other):
        '''void QGeoAreaMonitorInfo.__init__(QGeoAreaMonitorInfo other)'''
    def setNotificationParameters(self, parameters):
        '''void QGeoAreaMonitorInfo.setNotificationParameters(dict-of-str-object parameters)'''
    def notificationParameters(self):
        '''dict-of-str-object QGeoAreaMonitorInfo.notificationParameters()'''
        return {str():object()}
    def setPersistent(self, isPersistent):
        '''void QGeoAreaMonitorInfo.setPersistent(bool isPersistent)'''
    def isPersistent(self):
        '''bool QGeoAreaMonitorInfo.isPersistent()'''
        return bool()
    def setExpiration(self, expiry):
        '''void QGeoAreaMonitorInfo.setExpiration(QDateTime expiry)'''
    def expiration(self):
        '''QDateTime QGeoAreaMonitorInfo.expiration()'''
        return QDateTime()
    def setArea(self, newShape):
        '''void QGeoAreaMonitorInfo.setArea(QGeoShape newShape)'''
    def area(self):
        '''QGeoShape QGeoAreaMonitorInfo.area()'''
        return QGeoShape()
    def isValid(self):
        '''bool QGeoAreaMonitorInfo.isValid()'''
        return bool()
    def identifier(self):
        '''str QGeoAreaMonitorInfo.identifier()'''
        return str()
    def setName(self, name):
        '''void QGeoAreaMonitorInfo.setName(str name)'''
    def name(self):
        '''str QGeoAreaMonitorInfo.name()'''
        return str()
    def __ne__(self, other):
        '''bool QGeoAreaMonitorInfo.__ne__(QGeoAreaMonitorInfo other)'''
        return bool()
    def __eq__(self, other):
        '''bool QGeoAreaMonitorInfo.__eq__(QGeoAreaMonitorInfo other)'''
        return bool()


class QGeoAreaMonitorSource(QObject):
    """"""
    # Enum QGeoAreaMonitorSource.AreaMonitorFeature
    PersistentAreaMonitorFeature = 0
    AnyAreaMonitorFeature = 0

    # Enum QGeoAreaMonitorSource.Error
    AccessError = 0
    InsufficientPositionInfo = 0
    UnknownSourceError = 0
    NoError = 0

    def __init__(self, parent):
        '''void QGeoAreaMonitorSource.__init__(QObject parent)'''
    monitorExpired = pyqtSignal() # void monitorExpired(const QGeoAreaMonitorInfoamp;) - signal
    areaExited = pyqtSignal() # void areaExited(const QGeoAreaMonitorInfoamp;,const QGeoPositionInfoamp;) - signal
    areaEntered = pyqtSignal() # void areaEntered(const QGeoAreaMonitorInfoamp;,const QGeoPositionInfoamp;) - signal
    def activeMonitors(self):
        '''abstract list-of-QGeoAreaMonitorInfo QGeoAreaMonitorSource.activeMonitors()'''
        return [QGeoAreaMonitorInfo()]
    def activeMonitors(self, lookupArea):
        '''abstract list-of-QGeoAreaMonitorInfo QGeoAreaMonitorSource.activeMonitors(QGeoShape lookupArea)'''
        return [QGeoAreaMonitorInfo()]
    def requestUpdate(self, monitor, signal):
        '''abstract bool QGeoAreaMonitorSource.requestUpdate(QGeoAreaMonitorInfo monitor, str signal)'''
        return bool()
    def stopMonitoring(self, monitor):
        '''abstract bool QGeoAreaMonitorSource.stopMonitoring(QGeoAreaMonitorInfo monitor)'''
        return bool()
    def startMonitoring(self, monitor):
        '''abstract bool QGeoAreaMonitorSource.startMonitoring(QGeoAreaMonitorInfo monitor)'''
        return bool()
    def supportedAreaMonitorFeatures(self):
        '''abstract QGeoAreaMonitorSource.AreaMonitorFeatures QGeoAreaMonitorSource.supportedAreaMonitorFeatures()'''
        return QGeoAreaMonitorSource.AreaMonitorFeatures()
    def error(self):
        '''abstract QGeoAreaMonitorSource.Error QGeoAreaMonitorSource.error()'''
        return QGeoAreaMonitorSource.Error()
    error = pyqtSignal() # void error(QGeoAreaMonitorSource::Error) - signal
    def sourceName(self):
        '''str QGeoAreaMonitorSource.sourceName()'''
        return str()
    def positionInfoSource(self):
        '''QGeoPositionInfoSource QGeoAreaMonitorSource.positionInfoSource()'''
        return QGeoPositionInfoSource()
    def setPositionInfoSource(self, source):
        '''void QGeoAreaMonitorSource.setPositionInfoSource(QGeoPositionInfoSource source)'''
    def availableSources(self):
        '''static list-of-str QGeoAreaMonitorSource.availableSources()'''
        return [str()]
    def createSource(self, sourceName, parent):
        '''static QGeoAreaMonitorSource QGeoAreaMonitorSource.createSource(str sourceName, QObject parent)'''
        return QGeoAreaMonitorSource()
    def createDefaultSource(self, parent):
        '''static QGeoAreaMonitorSource QGeoAreaMonitorSource.createDefaultSource(QObject parent)'''
        return QGeoAreaMonitorSource()
    class AreaMonitorFeatures():
        """"""
        def __init__(self):
            '''QGeoAreaMonitorSource.AreaMonitorFeatures QGeoAreaMonitorSource.AreaMonitorFeatures.__init__()'''
            return QGeoAreaMonitorSource.AreaMonitorFeatures()
        def __init__(self):
            '''int QGeoAreaMonitorSource.AreaMonitorFeatures.__init__()'''
            return int()
        def __init__(self):
            '''void QGeoAreaMonitorSource.AreaMonitorFeatures.__init__()'''
        def __bool__(self):
            '''int QGeoAreaMonitorSource.AreaMonitorFeatures.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QGeoAreaMonitorSource.AreaMonitorFeatures.__ne__(QGeoAreaMonitorSource.AreaMonitorFeatures f)'''
            return bool()
        def __eq__(self, f):
            '''bool QGeoAreaMonitorSource.AreaMonitorFeatures.__eq__(QGeoAreaMonitorSource.AreaMonitorFeatures f)'''
            return bool()
        def __invert__(self):
            '''QGeoAreaMonitorSource.AreaMonitorFeatures QGeoAreaMonitorSource.AreaMonitorFeatures.__invert__()'''
            return QGeoAreaMonitorSource.AreaMonitorFeatures()
        def __and__(self, mask):
            '''QGeoAreaMonitorSource.AreaMonitorFeatures QGeoAreaMonitorSource.AreaMonitorFeatures.__and__(int mask)'''
            return QGeoAreaMonitorSource.AreaMonitorFeatures()
        def __xor__(self, f):
            '''QGeoAreaMonitorSource.AreaMonitorFeatures QGeoAreaMonitorSource.AreaMonitorFeatures.__xor__(QGeoAreaMonitorSource.AreaMonitorFeatures f)'''
            return QGeoAreaMonitorSource.AreaMonitorFeatures()
        def __xor__(self, f):
            '''QGeoAreaMonitorSource.AreaMonitorFeatures QGeoAreaMonitorSource.AreaMonitorFeatures.__xor__(int f)'''
            return QGeoAreaMonitorSource.AreaMonitorFeatures()
        def __or__(self, f):
            '''QGeoAreaMonitorSource.AreaMonitorFeatures QGeoAreaMonitorSource.AreaMonitorFeatures.__or__(QGeoAreaMonitorSource.AreaMonitorFeatures f)'''
            return QGeoAreaMonitorSource.AreaMonitorFeatures()
        def __or__(self, f):
            '''QGeoAreaMonitorSource.AreaMonitorFeatures QGeoAreaMonitorSource.AreaMonitorFeatures.__or__(int f)'''
            return QGeoAreaMonitorSource.AreaMonitorFeatures()
        def __int__(self):
            '''int QGeoAreaMonitorSource.AreaMonitorFeatures.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QGeoAreaMonitorSource.AreaMonitorFeatures QGeoAreaMonitorSource.AreaMonitorFeatures.__ixor__(QGeoAreaMonitorSource.AreaMonitorFeatures f)'''
            return QGeoAreaMonitorSource.AreaMonitorFeatures()
        def __ior__(self, f):
            '''QGeoAreaMonitorSource.AreaMonitorFeatures QGeoAreaMonitorSource.AreaMonitorFeatures.__ior__(QGeoAreaMonitorSource.AreaMonitorFeatures f)'''
            return QGeoAreaMonitorSource.AreaMonitorFeatures()
        def __iand__(self, mask):
            '''QGeoAreaMonitorSource.AreaMonitorFeatures QGeoAreaMonitorSource.AreaMonitorFeatures.__iand__(int mask)'''
            return QGeoAreaMonitorSource.AreaMonitorFeatures()


class QGeoShape():
    """"""
    # Enum QGeoShape.ShapeType
    UnknownType = 0
    RectangleType = 0
    CircleType = 0

    def __init__(self):
        '''void QGeoShape.__init__()'''
    def __init__(self, other):
        '''void QGeoShape.__init__(QGeoShape other)'''
    def toString(self):
        '''str QGeoShape.toString()'''
        return str()
    def center(self):
        '''QGeoCoordinate QGeoShape.center()'''
        return QGeoCoordinate()
    def extendShape(self, coordinate):
        '''void QGeoShape.extendShape(QGeoCoordinate coordinate)'''
    def __ne__(self, other):
        '''bool QGeoShape.__ne__(QGeoShape other)'''
        return bool()
    def __eq__(self, other):
        '''bool QGeoShape.__eq__(QGeoShape other)'''
        return bool()
    def contains(self, coordinate):
        '''bool QGeoShape.contains(QGeoCoordinate coordinate)'''
        return bool()
    def isEmpty(self):
        '''bool QGeoShape.isEmpty()'''
        return bool()
    def isValid(self):
        '''bool QGeoShape.isValid()'''
        return bool()
    def type(self):
        '''QGeoShape.ShapeType QGeoShape.type()'''
        return QGeoShape.ShapeType()


class QGeoCircle(QGeoShape):
    """"""
    def __init__(self):
        '''void QGeoCircle.__init__()'''
    def __init__(self, center, radius = None):
        '''void QGeoCircle.__init__(QGeoCoordinate center, float radius = -1)'''
    def __init__(self, other):
        '''void QGeoCircle.__init__(QGeoCircle other)'''
    def __init__(self, other):
        '''void QGeoCircle.__init__(QGeoShape other)'''
    def toString(self):
        '''str QGeoCircle.toString()'''
        return str()
    def translated(self, degreesLatitude, degreesLongitude):
        '''QGeoCircle QGeoCircle.translated(float degreesLatitude, float degreesLongitude)'''
        return QGeoCircle()
    def translate(self, degreesLatitude, degreesLongitude):
        '''void QGeoCircle.translate(float degreesLatitude, float degreesLongitude)'''
    def radius(self):
        '''float QGeoCircle.radius()'''
        return float()
    def setRadius(self, radius):
        '''void QGeoCircle.setRadius(float radius)'''
    def center(self):
        '''QGeoCoordinate QGeoCircle.center()'''
        return QGeoCoordinate()
    def setCenter(self, center):
        '''void QGeoCircle.setCenter(QGeoCoordinate center)'''
    def __ne__(self, other):
        '''bool QGeoCircle.__ne__(QGeoCircle other)'''
        return bool()
    def __eq__(self, other):
        '''bool QGeoCircle.__eq__(QGeoCircle other)'''
        return bool()


class QGeoCoordinate():
    """"""
    # Enum QGeoCoordinate.CoordinateFormat
    Degrees = 0
    DegreesWithHemisphere = 0
    DegreesMinutes = 0
    DegreesMinutesWithHemisphere = 0
    DegreesMinutesSeconds = 0
    DegreesMinutesSecondsWithHemisphere = 0

    # Enum QGeoCoordinate.CoordinateType
    InvalidCoordinate = 0
    Coordinate2D = 0
    Coordinate3D = 0

    def __init__(self):
        '''void QGeoCoordinate.__init__()'''
    def __init__(self, latitude, longitude):
        '''void QGeoCoordinate.__init__(float latitude, float longitude)'''
    def __init__(self, latitude, longitude, altitude):
        '''void QGeoCoordinate.__init__(float latitude, float longitude, float altitude)'''
    def __init__(self, other):
        '''void QGeoCoordinate.__init__(QGeoCoordinate other)'''
    def toString(self, format = None):
        '''str QGeoCoordinate.toString(QGeoCoordinate.CoordinateFormat format = QGeoCoordinate.DegreesMinutesSecondsWithHemisphere)'''
        return str()
    def atDistanceAndAzimuth(self, distance, azimuth, distanceUp = 0):
        '''QGeoCoordinate QGeoCoordinate.atDistanceAndAzimuth(float distance, float azimuth, float distanceUp = 0)'''
        return QGeoCoordinate()
    def azimuthTo(self, other):
        '''float QGeoCoordinate.azimuthTo(QGeoCoordinate other)'''
        return float()
    def distanceTo(self, other):
        '''float QGeoCoordinate.distanceTo(QGeoCoordinate other)'''
        return float()
    def altitude(self):
        '''float QGeoCoordinate.altitude()'''
        return float()
    def setAltitude(self, altitude):
        '''void QGeoCoordinate.setAltitude(float altitude)'''
    def longitude(self):
        '''float QGeoCoordinate.longitude()'''
        return float()
    def setLongitude(self, longitude):
        '''void QGeoCoordinate.setLongitude(float longitude)'''
    def latitude(self):
        '''float QGeoCoordinate.latitude()'''
        return float()
    def setLatitude(self, latitude):
        '''void QGeoCoordinate.setLatitude(float latitude)'''
    def type(self):
        '''QGeoCoordinate.CoordinateType QGeoCoordinate.type()'''
        return QGeoCoordinate.CoordinateType()
    def isValid(self):
        '''bool QGeoCoordinate.isValid()'''
        return bool()
    def __ne__(self, other):
        '''bool QGeoCoordinate.__ne__(QGeoCoordinate other)'''
        return bool()
    def __eq__(self, other):
        '''bool QGeoCoordinate.__eq__(QGeoCoordinate other)'''
        return bool()


class QGeoLocation():
    """"""
    def __init__(self):
        '''void QGeoLocation.__init__()'''
    def __init__(self, other):
        '''void QGeoLocation.__init__(QGeoLocation other)'''
    def isEmpty(self):
        '''bool QGeoLocation.isEmpty()'''
        return bool()
    def setBoundingBox(self, box):
        '''void QGeoLocation.setBoundingBox(QGeoRectangle box)'''
    def boundingBox(self):
        '''QGeoRectangle QGeoLocation.boundingBox()'''
        return QGeoRectangle()
    def setCoordinate(self, position):
        '''void QGeoLocation.setCoordinate(QGeoCoordinate position)'''
    def coordinate(self):
        '''QGeoCoordinate QGeoLocation.coordinate()'''
        return QGeoCoordinate()
    def setAddress(self, address):
        '''void QGeoLocation.setAddress(QGeoAddress address)'''
    def address(self):
        '''QGeoAddress QGeoLocation.address()'''
        return QGeoAddress()
    def __ne__(self, other):
        '''bool QGeoLocation.__ne__(QGeoLocation other)'''
        return bool()
    def __eq__(self, other):
        '''bool QGeoLocation.__eq__(QGeoLocation other)'''
        return bool()


class QGeoPositionInfo():
    """"""
    # Enum QGeoPositionInfo.Attribute
    Direction = 0
    GroundSpeed = 0
    VerticalSpeed = 0
    MagneticVariation = 0
    HorizontalAccuracy = 0
    VerticalAccuracy = 0

    def __init__(self):
        '''void QGeoPositionInfo.__init__()'''
    def __init__(self, coordinate, updateTime):
        '''void QGeoPositionInfo.__init__(QGeoCoordinate coordinate, QDateTime updateTime)'''
    def __init__(self, other):
        '''void QGeoPositionInfo.__init__(QGeoPositionInfo other)'''
    def hasAttribute(self, attribute):
        '''bool QGeoPositionInfo.hasAttribute(QGeoPositionInfo.Attribute attribute)'''
        return bool()
    def removeAttribute(self, attribute):
        '''void QGeoPositionInfo.removeAttribute(QGeoPositionInfo.Attribute attribute)'''
    def attribute(self, attribute):
        '''float QGeoPositionInfo.attribute(QGeoPositionInfo.Attribute attribute)'''
        return float()
    def setAttribute(self, attribute, value):
        '''void QGeoPositionInfo.setAttribute(QGeoPositionInfo.Attribute attribute, float value)'''
    def coordinate(self):
        '''QGeoCoordinate QGeoPositionInfo.coordinate()'''
        return QGeoCoordinate()
    def setCoordinate(self, coordinate):
        '''void QGeoPositionInfo.setCoordinate(QGeoCoordinate coordinate)'''
    def timestamp(self):
        '''QDateTime QGeoPositionInfo.timestamp()'''
        return QDateTime()
    def setTimestamp(self, timestamp):
        '''void QGeoPositionInfo.setTimestamp(QDateTime timestamp)'''
    def isValid(self):
        '''bool QGeoPositionInfo.isValid()'''
        return bool()
    def __ne__(self, other):
        '''bool QGeoPositionInfo.__ne__(QGeoPositionInfo other)'''
        return bool()
    def __eq__(self, other):
        '''bool QGeoPositionInfo.__eq__(QGeoPositionInfo other)'''
        return bool()


class QGeoPositionInfoSource(QObject):
    """"""
    # Enum QGeoPositionInfoSource.PositioningMethod
    NoPositioningMethods = 0
    SatellitePositioningMethods = 0
    NonSatellitePositioningMethods = 0
    AllPositioningMethods = 0

    # Enum QGeoPositionInfoSource.Error
    AccessError = 0
    ClosedError = 0
    UnknownSourceError = 0
    NoError = 0

    def __init__(self, parent):
        '''void QGeoPositionInfoSource.__init__(QObject parent)'''
    updateTimeout = pyqtSignal() # void updateTimeout() - signal
    positionUpdated = pyqtSignal() # void positionUpdated(const QGeoPositionInfoamp;) - signal
    def requestUpdate(self, timeout = 0):
        '''abstract void QGeoPositionInfoSource.requestUpdate(int timeout = 0)'''
    def stopUpdates(self):
        '''abstract void QGeoPositionInfoSource.stopUpdates()'''
    def startUpdates(self):
        '''abstract void QGeoPositionInfoSource.startUpdates()'''
    def error(self):
        '''abstract QGeoPositionInfoSource.Error QGeoPositionInfoSource.error()'''
        return QGeoPositionInfoSource.Error()
    error = pyqtSignal() # void error(QGeoPositionInfoSource::Error) - signal
    def availableSources(self):
        '''static list-of-str QGeoPositionInfoSource.availableSources()'''
        return [str()]
    def createSource(self, sourceName, parent):
        '''static QGeoPositionInfoSource QGeoPositionInfoSource.createSource(str sourceName, QObject parent)'''
        return QGeoPositionInfoSource()
    def createDefaultSource(self, parent):
        '''static QGeoPositionInfoSource QGeoPositionInfoSource.createDefaultSource(QObject parent)'''
        return QGeoPositionInfoSource()
    def sourceName(self):
        '''str QGeoPositionInfoSource.sourceName()'''
        return str()
    def minimumUpdateInterval(self):
        '''abstract int QGeoPositionInfoSource.minimumUpdateInterval()'''
        return int()
    def supportedPositioningMethods(self):
        '''abstract QGeoPositionInfoSource.PositioningMethods QGeoPositionInfoSource.supportedPositioningMethods()'''
        return QGeoPositionInfoSource.PositioningMethods()
    def lastKnownPosition(self, fromSatellitePositioningMethodsOnly = False):
        '''abstract QGeoPositionInfo QGeoPositionInfoSource.lastKnownPosition(bool fromSatellitePositioningMethodsOnly = False)'''
        return QGeoPositionInfo()
    def preferredPositioningMethods(self):
        '''QGeoPositionInfoSource.PositioningMethods QGeoPositionInfoSource.preferredPositioningMethods()'''
        return QGeoPositionInfoSource.PositioningMethods()
    def setPreferredPositioningMethods(self, methods):
        '''void QGeoPositionInfoSource.setPreferredPositioningMethods(QGeoPositionInfoSource.PositioningMethods methods)'''
    def updateInterval(self):
        '''int QGeoPositionInfoSource.updateInterval()'''
        return int()
    def setUpdateInterval(self, msec):
        '''void QGeoPositionInfoSource.setUpdateInterval(int msec)'''
    class PositioningMethods():
        """"""
        def __init__(self):
            '''QGeoPositionInfoSource.PositioningMethods QGeoPositionInfoSource.PositioningMethods.__init__()'''
            return QGeoPositionInfoSource.PositioningMethods()
        def __init__(self):
            '''int QGeoPositionInfoSource.PositioningMethods.__init__()'''
            return int()
        def __init__(self):
            '''void QGeoPositionInfoSource.PositioningMethods.__init__()'''
        def __bool__(self):
            '''int QGeoPositionInfoSource.PositioningMethods.__bool__()'''
            return int()
        def __ne__(self, f):
            '''bool QGeoPositionInfoSource.PositioningMethods.__ne__(QGeoPositionInfoSource.PositioningMethods f)'''
            return bool()
        def __eq__(self, f):
            '''bool QGeoPositionInfoSource.PositioningMethods.__eq__(QGeoPositionInfoSource.PositioningMethods f)'''
            return bool()
        def __invert__(self):
            '''QGeoPositionInfoSource.PositioningMethods QGeoPositionInfoSource.PositioningMethods.__invert__()'''
            return QGeoPositionInfoSource.PositioningMethods()
        def __and__(self, mask):
            '''QGeoPositionInfoSource.PositioningMethods QGeoPositionInfoSource.PositioningMethods.__and__(int mask)'''
            return QGeoPositionInfoSource.PositioningMethods()
        def __xor__(self, f):
            '''QGeoPositionInfoSource.PositioningMethods QGeoPositionInfoSource.PositioningMethods.__xor__(QGeoPositionInfoSource.PositioningMethods f)'''
            return QGeoPositionInfoSource.PositioningMethods()
        def __xor__(self, f):
            '''QGeoPositionInfoSource.PositioningMethods QGeoPositionInfoSource.PositioningMethods.__xor__(int f)'''
            return QGeoPositionInfoSource.PositioningMethods()
        def __or__(self, f):
            '''QGeoPositionInfoSource.PositioningMethods QGeoPositionInfoSource.PositioningMethods.__or__(QGeoPositionInfoSource.PositioningMethods f)'''
            return QGeoPositionInfoSource.PositioningMethods()
        def __or__(self, f):
            '''QGeoPositionInfoSource.PositioningMethods QGeoPositionInfoSource.PositioningMethods.__or__(int f)'''
            return QGeoPositionInfoSource.PositioningMethods()
        def __int__(self):
            '''int QGeoPositionInfoSource.PositioningMethods.__int__()'''
            return int()
        def __ixor__(self, f):
            '''QGeoPositionInfoSource.PositioningMethods QGeoPositionInfoSource.PositioningMethods.__ixor__(QGeoPositionInfoSource.PositioningMethods f)'''
            return QGeoPositionInfoSource.PositioningMethods()
        def __ior__(self, f):
            '''QGeoPositionInfoSource.PositioningMethods QGeoPositionInfoSource.PositioningMethods.__ior__(QGeoPositionInfoSource.PositioningMethods f)'''
            return QGeoPositionInfoSource.PositioningMethods()
        def __iand__(self, mask):
            '''QGeoPositionInfoSource.PositioningMethods QGeoPositionInfoSource.PositioningMethods.__iand__(int mask)'''
            return QGeoPositionInfoSource.PositioningMethods()


class QGeoRectangle(QGeoShape):
    """"""
    def __init__(self):
        '''void QGeoRectangle.__init__()'''
    def __init__(self, center, degreesWidth, degreesHeight):
        '''void QGeoRectangle.__init__(QGeoCoordinate center, float degreesWidth, float degreesHeight)'''
    def __init__(self, topLeft, bottomRight):
        '''void QGeoRectangle.__init__(QGeoCoordinate topLeft, QGeoCoordinate bottomRight)'''
    def __init__(self, coordinates):
        '''void QGeoRectangle.__init__(list-of-QGeoCoordinate coordinates)'''
    def __init__(self, other):
        '''void QGeoRectangle.__init__(QGeoRectangle other)'''
    def __init__(self, other):
        '''void QGeoRectangle.__init__(QGeoShape other)'''
    def toString(self):
        '''str QGeoRectangle.toString()'''
        return str()
    def __or__(self, rectangle):
        '''QGeoRectangle QGeoRectangle.__or__(QGeoRectangle rectangle)'''
        return QGeoRectangle()
    def __ior__(self, rectangle):
        '''QGeoRectangle QGeoRectangle.__ior__(QGeoRectangle rectangle)'''
        return QGeoRectangle()
    def united(self, rectangle):
        '''QGeoRectangle QGeoRectangle.united(QGeoRectangle rectangle)'''
        return QGeoRectangle()
    def translated(self, degreesLatitude, degreesLongitude):
        '''QGeoRectangle QGeoRectangle.translated(float degreesLatitude, float degreesLongitude)'''
        return QGeoRectangle()
    def translate(self, degreesLatitude, degreesLongitude):
        '''void QGeoRectangle.translate(float degreesLatitude, float degreesLongitude)'''
    def intersects(self, rectangle):
        '''bool QGeoRectangle.intersects(QGeoRectangle rectangle)'''
        return bool()
    def contains(self, rectangle):
        '''bool QGeoRectangle.contains(QGeoRectangle rectangle)'''
        return bool()
    def height(self):
        '''float QGeoRectangle.height()'''
        return float()
    def setHeight(self, degreesHeight):
        '''void QGeoRectangle.setHeight(float degreesHeight)'''
    def width(self):
        '''float QGeoRectangle.width()'''
        return float()
    def setWidth(self, degreesWidth):
        '''void QGeoRectangle.setWidth(float degreesWidth)'''
    def center(self):
        '''QGeoCoordinate QGeoRectangle.center()'''
        return QGeoCoordinate()
    def setCenter(self, center):
        '''void QGeoRectangle.setCenter(QGeoCoordinate center)'''
    def bottomRight(self):
        '''QGeoCoordinate QGeoRectangle.bottomRight()'''
        return QGeoCoordinate()
    def setBottomRight(self, bottomRight):
        '''void QGeoRectangle.setBottomRight(QGeoCoordinate bottomRight)'''
    def bottomLeft(self):
        '''QGeoCoordinate QGeoRectangle.bottomLeft()'''
        return QGeoCoordinate()
    def setBottomLeft(self, bottomLeft):
        '''void QGeoRectangle.setBottomLeft(QGeoCoordinate bottomLeft)'''
    def topRight(self):
        '''QGeoCoordinate QGeoRectangle.topRight()'''
        return QGeoCoordinate()
    def setTopRight(self, topRight):
        '''void QGeoRectangle.setTopRight(QGeoCoordinate topRight)'''
    def topLeft(self):
        '''QGeoCoordinate QGeoRectangle.topLeft()'''
        return QGeoCoordinate()
    def setTopLeft(self, topLeft):
        '''void QGeoRectangle.setTopLeft(QGeoCoordinate topLeft)'''
    def __ne__(self, other):
        '''bool QGeoRectangle.__ne__(QGeoRectangle other)'''
        return bool()
    def __eq__(self, other):
        '''bool QGeoRectangle.__eq__(QGeoRectangle other)'''
        return bool()


class QGeoSatelliteInfo():
    """"""
    # Enum QGeoSatelliteInfo.SatelliteSystem
    Undefined = 0
    GPS = 0
    GLONASS = 0

    # Enum QGeoSatelliteInfo.Attribute
    Elevation = 0
    Azimuth = 0

    def __init__(self):
        '''void QGeoSatelliteInfo.__init__()'''
    def __init__(self, other):
        '''void QGeoSatelliteInfo.__init__(QGeoSatelliteInfo other)'''
    def hasAttribute(self, attribute):
        '''bool QGeoSatelliteInfo.hasAttribute(QGeoSatelliteInfo.Attribute attribute)'''
        return bool()
    def removeAttribute(self, attribute):
        '''void QGeoSatelliteInfo.removeAttribute(QGeoSatelliteInfo.Attribute attribute)'''
    def attribute(self, attribute):
        '''float QGeoSatelliteInfo.attribute(QGeoSatelliteInfo.Attribute attribute)'''
        return float()
    def setAttribute(self, attribute, value):
        '''void QGeoSatelliteInfo.setAttribute(QGeoSatelliteInfo.Attribute attribute, float value)'''
    def signalStrength(self):
        '''int QGeoSatelliteInfo.signalStrength()'''
        return int()
    def setSignalStrength(self, signalStrength):
        '''void QGeoSatelliteInfo.setSignalStrength(int signalStrength)'''
    def satelliteIdentifier(self):
        '''int QGeoSatelliteInfo.satelliteIdentifier()'''
        return int()
    def setSatelliteIdentifier(self, satId):
        '''void QGeoSatelliteInfo.setSatelliteIdentifier(int satId)'''
    def satelliteSystem(self):
        '''QGeoSatelliteInfo.SatelliteSystem QGeoSatelliteInfo.satelliteSystem()'''
        return QGeoSatelliteInfo.SatelliteSystem()
    def setSatelliteSystem(self, system):
        '''void QGeoSatelliteInfo.setSatelliteSystem(QGeoSatelliteInfo.SatelliteSystem system)'''
    def __ne__(self, other):
        '''bool QGeoSatelliteInfo.__ne__(QGeoSatelliteInfo other)'''
        return bool()
    def __eq__(self, other):
        '''bool QGeoSatelliteInfo.__eq__(QGeoSatelliteInfo other)'''
        return bool()


class QGeoSatelliteInfoSource(QObject):
    """"""
    # Enum QGeoSatelliteInfoSource.Error
    AccessError = 0
    ClosedError = 0
    NoError = 0
    UnknownSourceError = 0

    def __init__(self, parent):
        '''void QGeoSatelliteInfoSource.__init__(QObject parent)'''
    requestTimeout = pyqtSignal() # void requestTimeout() - signal
    satellitesInUseUpdated = pyqtSignal() # void satellitesInUseUpdated(const QListlt;QGeoSatelliteInfogt;amp;) - signal
    satellitesInViewUpdated = pyqtSignal() # void satellitesInViewUpdated(const QListlt;QGeoSatelliteInfogt;amp;) - signal
    def requestUpdate(self, timeout = 0):
        '''abstract void QGeoSatelliteInfoSource.requestUpdate(int timeout = 0)'''
    def stopUpdates(self):
        '''abstract void QGeoSatelliteInfoSource.stopUpdates()'''
    def startUpdates(self):
        '''abstract void QGeoSatelliteInfoSource.startUpdates()'''
    def error(self):
        '''abstract QGeoSatelliteInfoSource.Error QGeoSatelliteInfoSource.error()'''
        return QGeoSatelliteInfoSource.Error()
    error = pyqtSignal() # void error(QGeoSatelliteInfoSource::Error) - signal
    def minimumUpdateInterval(self):
        '''abstract int QGeoSatelliteInfoSource.minimumUpdateInterval()'''
        return int()
    def updateInterval(self):
        '''int QGeoSatelliteInfoSource.updateInterval()'''
        return int()
    def setUpdateInterval(self, msec):
        '''void QGeoSatelliteInfoSource.setUpdateInterval(int msec)'''
    def sourceName(self):
        '''str QGeoSatelliteInfoSource.sourceName()'''
        return str()
    def availableSources(self):
        '''static list-of-str QGeoSatelliteInfoSource.availableSources()'''
        return [str()]
    def createSource(self, sourceName, parent):
        '''static QGeoSatelliteInfoSource QGeoSatelliteInfoSource.createSource(str sourceName, QObject parent)'''
        return QGeoSatelliteInfoSource()
    def createDefaultSource(self, parent):
        '''static QGeoSatelliteInfoSource QGeoSatelliteInfoSource.createDefaultSource(QObject parent)'''
        return QGeoSatelliteInfoSource()


class QNmeaPositionInfoSource(QGeoPositionInfoSource):
    """"""
    # Enum QNmeaPositionInfoSource.UpdateMode
    RealTimeMode = 0
    SimulationMode = 0

    def __init__(self, updateMode, parent = None):
        '''void QNmeaPositionInfoSource.__init__(QNmeaPositionInfoSource.UpdateMode updateMode, QObject parent = None)'''
    def userEquivalentRangeError(self):
        '''float QNmeaPositionInfoSource.userEquivalentRangeError()'''
        return float()
    def setUserEquivalentRangeError(self, uere):
        '''void QNmeaPositionInfoSource.setUserEquivalentRangeError(float uere)'''
    def parsePosInfoFromNmeaData(self, data, size, posInfo, hasFix):
        '''bool QNmeaPositionInfoSource.parsePosInfoFromNmeaData(str data, int size, QGeoPositionInfo posInfo, bool hasFix)'''
        return bool()
    def requestUpdate(self, timeout = 0):
        '''void QNmeaPositionInfoSource.requestUpdate(int timeout = 0)'''
    def stopUpdates(self):
        '''void QNmeaPositionInfoSource.stopUpdates()'''
    def startUpdates(self):
        '''void QNmeaPositionInfoSource.startUpdates()'''
    def error(self):
        '''QGeoPositionInfoSource.Error QNmeaPositionInfoSource.error()'''
        return QGeoPositionInfoSource.Error()
    def minimumUpdateInterval(self):
        '''int QNmeaPositionInfoSource.minimumUpdateInterval()'''
        return int()
    def supportedPositioningMethods(self):
        '''QGeoPositionInfoSource.PositioningMethods QNmeaPositionInfoSource.supportedPositioningMethods()'''
        return QGeoPositionInfoSource.PositioningMethods()
    def lastKnownPosition(self, fromSatellitePositioningMethodsOnly = False):
        '''QGeoPositionInfo QNmeaPositionInfoSource.lastKnownPosition(bool fromSatellitePositioningMethodsOnly = False)'''
        return QGeoPositionInfo()
    def setUpdateInterval(self, msec):
        '''void QNmeaPositionInfoSource.setUpdateInterval(int msec)'''
    def device(self):
        '''QIODevice QNmeaPositionInfoSource.device()'''
        return QIODevice()
    def setDevice(self, source):
        '''void QNmeaPositionInfoSource.setDevice(QIODevice source)'''
    def updateMode(self):
        '''QNmeaPositionInfoSource.UpdateMode QNmeaPositionInfoSource.updateMode()'''
        return QNmeaPositionInfoSource.UpdateMode()





class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class QGraphicsSvgItem(QGraphicsObject):
    """"""
    def __init__(self, parent = None):
        '''void QGraphicsSvgItem.__init__(QGraphicsItem parent = None)'''
    def __init__(self, fileName, parent = None):
        '''void QGraphicsSvgItem.__init__(QString fileName, QGraphicsItem parent = None)'''
    def type(self):
        '''int QGraphicsSvgItem.type()'''
        return int()
    def paint(self, painter, option, widget = None):
        '''void QGraphicsSvgItem.paint(QPainter painter, QStyleOptionGraphicsItem option, QWidget widget = None)'''
    def boundingRect(self):
        '''QRectF QGraphicsSvgItem.boundingRect()'''
        return QRectF()
    def maximumCacheSize(self):
        '''QSize QGraphicsSvgItem.maximumCacheSize()'''
        return QSize()
    def setMaximumCacheSize(self, size):
        '''void QGraphicsSvgItem.setMaximumCacheSize(QSize size)'''
    def isCachingEnabled(self):
        '''bool QGraphicsSvgItem.isCachingEnabled()'''
        return bool()
    def setCachingEnabled(self):
        '''bool QGraphicsSvgItem.setCachingEnabled()'''
        return bool()
    def elementId(self):
        '''QString QGraphicsSvgItem.elementId()'''
        return QString()
    def setElementId(self, id):
        '''void QGraphicsSvgItem.setElementId(QString id)'''
    def renderer(self):
        '''QSvgRenderer QGraphicsSvgItem.renderer()'''
        return QSvgRenderer()
    def setSharedRenderer(self, renderer):
        '''void QGraphicsSvgItem.setSharedRenderer(QSvgRenderer renderer)'''


class QSvgGenerator(QPaintDevice):
    """"""
    def __init__(self):
        '''void QSvgGenerator.__init__()'''
    def metric(self, metric):
        '''int QSvgGenerator.metric(QPaintDevice.PaintDeviceMetric metric)'''
        return int()
    def paintEngine(self):
        '''QPaintEngine QSvgGenerator.paintEngine()'''
        return QPaintEngine()
    def setViewBox(self, viewBox):
        '''void QSvgGenerator.setViewBox(QRect viewBox)'''
    def setViewBox(self, viewBox):
        '''void QSvgGenerator.setViewBox(QRectF viewBox)'''
    def viewBoxF(self):
        '''QRectF QSvgGenerator.viewBoxF()'''
        return QRectF()
    def viewBox(self):
        '''QRect QSvgGenerator.viewBox()'''
        return QRect()
    def setDescription(self, description):
        '''void QSvgGenerator.setDescription(QString description)'''
    def description(self):
        '''QString QSvgGenerator.description()'''
        return QString()
    def setTitle(self, title):
        '''void QSvgGenerator.setTitle(QString title)'''
    def title(self):
        '''QString QSvgGenerator.title()'''
        return QString()
    def setResolution(self, resolution):
        '''void QSvgGenerator.setResolution(int resolution)'''
    def resolution(self):
        '''int QSvgGenerator.resolution()'''
        return int()
    def setOutputDevice(self, outputDevice):
        '''void QSvgGenerator.setOutputDevice(QIODevice outputDevice)'''
    def outputDevice(self):
        '''QIODevice QSvgGenerator.outputDevice()'''
        return QIODevice()
    def setFileName(self, fileName):
        '''void QSvgGenerator.setFileName(QString fileName)'''
    def fileName(self):
        '''QString QSvgGenerator.fileName()'''
        return QString()
    def setSize(self, size):
        '''void QSvgGenerator.setSize(QSize size)'''
    def size(self):
        '''QSize QSvgGenerator.size()'''
        return QSize()


class QSvgRenderer(QObject):
    """"""
    def __init__(self, parent = None):
        '''void QSvgRenderer.__init__(QObject parent = None)'''
    def __init__(self, filename, parent = None):
        '''void QSvgRenderer.__init__(QString filename, QObject parent = None)'''
    def __init__(self, contents, parent = None):
        '''void QSvgRenderer.__init__(QByteArray contents, QObject parent = None)'''
    def __init__(self, contents, parent = None):
        '''void QSvgRenderer.__init__(QXmlStreamReader contents, QObject parent = None)'''
    repaintNeeded = pyqtSignal() # void repaintNeeded() - signal
    def render(self, p):
        '''void QSvgRenderer.render(QPainter p)'''
    def render(self, p, bounds):
        '''void QSvgRenderer.render(QPainter p, QRectF bounds)'''
    def render(self, painter, elementId, bounds = QRectF()):
        '''void QSvgRenderer.render(QPainter painter, QString elementId, QRectF bounds = QRectF())'''
    def load(self, filename):
        '''bool QSvgRenderer.load(QString filename)'''
        return bool()
    def load(self, contents):
        '''bool QSvgRenderer.load(QByteArray contents)'''
        return bool()
    def load(self, contents):
        '''bool QSvgRenderer.load(QXmlStreamReader contents)'''
        return bool()
    def animationDuration(self):
        '''int QSvgRenderer.animationDuration()'''
        return int()
    def setCurrentFrame(self):
        '''int QSvgRenderer.setCurrentFrame()'''
        return int()
    def currentFrame(self):
        '''int QSvgRenderer.currentFrame()'''
        return int()
    def setFramesPerSecond(self, num):
        '''void QSvgRenderer.setFramesPerSecond(int num)'''
    def framesPerSecond(self):
        '''int QSvgRenderer.framesPerSecond()'''
        return int()
    def boundsOnElement(self, id):
        '''QRectF QSvgRenderer.boundsOnElement(QString id)'''
        return QRectF()
    def animated(self):
        '''bool QSvgRenderer.animated()'''
        return bool()
    def setViewBox(self, viewbox):
        '''void QSvgRenderer.setViewBox(QRect viewbox)'''
    def setViewBox(self, viewbox):
        '''void QSvgRenderer.setViewBox(QRectF viewbox)'''
    def viewBoxF(self):
        '''QRectF QSvgRenderer.viewBoxF()'''
        return QRectF()
    def viewBox(self):
        '''QRect QSvgRenderer.viewBox()'''
        return QRect()
    def elementExists(self, id):
        '''bool QSvgRenderer.elementExists(QString id)'''
        return bool()
    def defaultSize(self):
        '''QSize QSvgRenderer.defaultSize()'''
        return QSize()
    def matrixForElement(self, id):
        '''QMatrix QSvgRenderer.matrixForElement(QString id)'''
        return QMatrix()
    def isValid(self):
        '''bool QSvgRenderer.isValid()'''
        return bool()


class QSvgWidget(QWidget):
    """"""
    def __init__(self, parent = None):
        '''void QSvgWidget.__init__(QWidget parent = None)'''
    def __init__(self, file, parent = None):
        '''void QSvgWidget.__init__(QString file, QWidget parent = None)'''
    def paintEvent(self, event):
        '''void QSvgWidget.paintEvent(QPaintEvent event)'''
    def load(self, file):
        '''void QSvgWidget.load(QString file)'''
    def load(self, contents):
        '''void QSvgWidget.load(QByteArray contents)'''
    def sizeHint(self):
        '''QSize QSvgWidget.sizeHint()'''
        return QSize()
    def renderer(self):
        '''QSvgRenderer QSvgWidget.renderer()'''
        return QSvgRenderer()





class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QX11Info():
    """"""
    def __init__(self):
        '''QX11Info QX11Info.__init__()'''
        return QX11Info()
    def connection(self):
        '''static xcb_connection_t QX11Info.connection()'''
        return xcb_connection_t()
    def display(self):
        '''static Display QX11Info.display()'''
        return Display()
    def setNextStartupId(self, id):
        '''static void QX11Info.setNextStartupId(QByteArray id)'''
    def nextStartupId(self):
        '''static QByteArray QX11Info.nextStartupId()'''
        return QByteArray()
    def getTimestamp(self):
        '''static int QX11Info.getTimestamp()'''
        return int()
    def setAppUserTime(self, time):
        '''static void QX11Info.setAppUserTime(int time)'''
    def setAppTime(self, time):
        '''static void QX11Info.setAppTime(int time)'''
    def appUserTime(self):
        '''static int QX11Info.appUserTime()'''
        return int()
    def appTime(self):
        '''static int QX11Info.appTime()'''
        return int()
    def appScreen(self):
        '''static int QX11Info.appScreen()'''
        return int()
    def appRootWindow(self, screen = None):
        '''static int QX11Info.appRootWindow(int screen = -1)'''
        return int()
    def appDpiY(self, screen = None):
        '''static int QX11Info.appDpiY(int screen = -1)'''
        return int()
    def appDpiX(self, screen = None):
        '''static int QX11Info.appDpiX(int screen = -1)'''
        return int()
    def isPlatformX11(self):
        '''static bool QX11Info.isPlatformX11()'''
        return bool()





# AUTO-GENERATED FILE -- DO NOT EDIT


__package__ = None

def add():
  pass

def adpcm2lin():
  pass

def alaw2lin():
  pass

def avg():
  pass

def avgpp():
  pass

def bias():
  pass

def cross():
  pass

class error(Exception):

  pass

def findfactor():
  pass

def findfit():
  pass

def findmax():
  pass

def getsample():
  pass

def lin2adpcm():
  pass

def lin2alaw():
  pass

def lin2lin():
  pass

def lin2ulaw():
  pass

def max():
  pass

def maxpp():
  pass

def minmax():
  pass

def mul():
  pass

def ratecv():
  pass

def reverse():
  pass

def rms():
  pass

def tomono():
  pass

def tostereo():
  pass

def ulaw2lin():
  pass




class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

from QtWidgets import *

import datetime

class QSignalSpy(QObject):
    """"""
    def __init__(self, signal):
        '''void QSignalSpy.__init__(signal signal)'''
    def __delitem__(self, i):
        '''void QSignalSpy.__delitem__(int i)'''
    def __setitem__(self, i, value):
        '''void QSignalSpy.__setitem__(int i, list-of-QVariant value)'''
    def __getitem__(self, i):
        '''list-of-QVariant QSignalSpy.__getitem__(int i)'''
        return [QVariant()]
    def __len__(self):
        '''int QSignalSpy.__len__()'''
        return int()
    def wait(self, timeout = 5000):
        '''bool QSignalSpy.wait(int timeout = 5000)'''
        return bool()
    def signal(self):
        '''QByteArray QSignalSpy.signal()'''
        return QByteArray()
    def isValid(self):
        '''bool QSignalSpy.isValid()'''
        return bool()


class QTest():
    """"""
    # Enum QTest.MouseAction
    MousePress = 0
    MouseRelease = 0
    MouseClick = 0
    MouseDClick = 0
    MouseMove = 0

    # Enum QTest.KeyAction
    Press = 0
    Release = 0
    Click = 0

    def touchEvent(self, widget, device):
        '''static QTest.QTouchEventSequence QTest.touchEvent(QWidget widget, QTouchDevice device)'''
        return QTest.QTouchEventSequence()
    def touchEvent(self, window, device):
        '''static QTest.QTouchEventSequence QTest.touchEvent(QWindow window, QTouchDevice device)'''
        return QTest.QTouchEventSequence()
    def qWaitForWindowExposed(self, window, timeout = 5000):
        '''static bool QTest.qWaitForWindowExposed(QWindow window, int timeout = 5000)'''
        return bool()
    def qWaitForWindowExposed(self, widget, timeout = 1000):
        '''static bool QTest.qWaitForWindowExposed(QWidget widget, int timeout = 1000)'''
        return bool()
    def qWaitForWindowActive(self, window, timeout = 5000):
        '''static bool QTest.qWaitForWindowActive(QWindow window, int timeout = 5000)'''
        return bool()
    def qWaitForWindowActive(self, widget, timeout = 1000):
        '''static bool QTest.qWaitForWindowActive(QWidget widget, int timeout = 1000)'''
        return bool()
    def qWait(self, ms):
        '''static void QTest.qWait(int ms)'''
    def waitForEvents(self):
        '''static void QTest.waitForEvents()'''
    def mouseEvent(self, action, widget, button, modifier, pos, delay = None):
        '''static void QTest.mouseEvent(QTest.MouseAction action, QWidget widget, Qt.MouseButton button, Qt.KeyboardModifiers modifier, QPoint pos, int delay = -1)'''
    def mouseEvent(self, action, window, button, modifier, pos, delay = None):
        '''static void QTest.mouseEvent(QTest.MouseAction action, QWindow window, Qt.MouseButton button, Qt.KeyboardModifiers modifier, QPoint pos, int delay = -1)'''
    def mouseRelease(self, widget, button, modifier = 0, pos = QPoint(), delay = None):
        '''static void QTest.mouseRelease(QWidget widget, Qt.MouseButton button, Qt.KeyboardModifiers modifier = 0, QPoint pos = QPoint(), int delay = -1)'''
    def mouseRelease(self, window, button, modifier = 0, pos = QPoint(), delay = None):
        '''static void QTest.mouseRelease(QWindow window, Qt.MouseButton button, Qt.KeyboardModifiers modifier = 0, QPoint pos = QPoint(), int delay = -1)'''
    def mousePress(self, widget, button, modifier = 0, pos = QPoint(), delay = None):
        '''static void QTest.mousePress(QWidget widget, Qt.MouseButton button, Qt.KeyboardModifiers modifier = 0, QPoint pos = QPoint(), int delay = -1)'''
    def mousePress(self, window, button, modifier = 0, pos = QPoint(), delay = None):
        '''static void QTest.mousePress(QWindow window, Qt.MouseButton button, Qt.KeyboardModifiers modifier = 0, QPoint pos = QPoint(), int delay = -1)'''
    def mouseMove(self, widget, pos = QPoint(), delay = None):
        '''static void QTest.mouseMove(QWidget widget, QPoint pos = QPoint(), int delay = -1)'''
    def mouseMove(self, window, pos = QPoint(), delay = None):
        '''static void QTest.mouseMove(QWindow window, QPoint pos = QPoint(), int delay = -1)'''
    def mouseDClick(self, widget, button, modifier = 0, pos = QPoint(), delay = None):
        '''static void QTest.mouseDClick(QWidget widget, Qt.MouseButton button, Qt.KeyboardModifiers modifier = 0, QPoint pos = QPoint(), int delay = -1)'''
    def mouseDClick(self, window, button, modifier = 0, pos = QPoint(), delay = None):
        '''static void QTest.mouseDClick(QWindow window, Qt.MouseButton button, Qt.KeyboardModifiers modifier = 0, QPoint pos = QPoint(), int delay = -1)'''
    def mouseClick(self, widget, button, modifier = 0, pos = QPoint(), delay = None):
        '''static void QTest.mouseClick(QWidget widget, Qt.MouseButton button, Qt.KeyboardModifiers modifier = 0, QPoint pos = QPoint(), int delay = -1)'''
    def mouseClick(self, window, button, modifier = 0, pos = QPoint(), delay = None):
        '''static void QTest.mouseClick(QWindow window, Qt.MouseButton button, Qt.KeyboardModifiers modifier = 0, QPoint pos = QPoint(), int delay = -1)'''
    def keyRelease(self, widget, key, modifier = None, delay = None):
        '''static void QTest.keyRelease(QWidget widget, Qt.Key key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyRelease(self, widget, key, modifier = None, delay = None):
        '''static void QTest.keyRelease(QWidget widget, str key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyRelease(self, window, key, modifier = None, delay = None):
        '''static void QTest.keyRelease(QWindow window, str key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyRelease(self, window, key, modifier = None, delay = None):
        '''static void QTest.keyRelease(QWindow window, Qt.Key key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyPress(self, widget, key, modifier = None, delay = None):
        '''static void QTest.keyPress(QWidget widget, Qt.Key key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyPress(self, widget, key, modifier = None, delay = None):
        '''static void QTest.keyPress(QWidget widget, str key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyPress(self, window, key, modifier = None, delay = None):
        '''static void QTest.keyPress(QWindow window, str key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyPress(self, window, key, modifier = None, delay = None):
        '''static void QTest.keyPress(QWindow window, Qt.Key key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyEvent(self, action, widget, key, modifier = None, delay = None):
        '''static void QTest.keyEvent(QTest.KeyAction action, QWidget widget, Qt.Key key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyEvent(self, action, widget, ascii, modifier = None, delay = None):
        '''static void QTest.keyEvent(QTest.KeyAction action, QWidget widget, str ascii, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyEvent(self, action, window, ascii, modifier = None, delay = None):
        '''static void QTest.keyEvent(QTest.KeyAction action, QWindow window, str ascii, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyEvent(self, action, window, key, modifier = None, delay = None):
        '''static void QTest.keyEvent(QTest.KeyAction action, QWindow window, Qt.Key key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyClicks(self, widget, sequence, modifier = None, delay = None):
        '''static void QTest.keyClicks(QWidget widget, str sequence, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyClick(self, widget, key, modifier = None, delay = None):
        '''static void QTest.keyClick(QWidget widget, Qt.Key key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyClick(self, widget, key, modifier = None, delay = None):
        '''static void QTest.keyClick(QWidget widget, str key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyClick(self, window, key, modifier = None, delay = None):
        '''static void QTest.keyClick(QWindow window, Qt.Key key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def keyClick(self, window, key, modifier = None, delay = None):
        '''static void QTest.keyClick(QWindow window, str key, Qt.KeyboardModifiers modifier = Qt.NoModifier, int delay = -1)'''
    def qSleep(self, ms):
        '''static void QTest.qSleep(int ms)'''
    class QTouchEventSequence():
        """"""
        def __init__(self):
            '''QTest.QTouchEventSequence QTest.QTouchEventSequence.__init__()'''
            return QTest.QTouchEventSequence()
        def commit(self, processEvents = True):
            '''void QTest.QTouchEventSequence.commit(bool processEvents = True)'''
        def stationary(self, touchId):
            '''QTest.QTouchEventSequence QTest.QTouchEventSequence.stationary(int touchId)'''
            return QTest.QTouchEventSequence()
        def release(self, touchId, pt, window = None):
            '''QTest.QTouchEventSequence QTest.QTouchEventSequence.release(int touchId, QPoint pt, QWindow window = None)'''
            return QTest.QTouchEventSequence()
        def release(self, touchId, pt, widget):
            '''QTest.QTouchEventSequence QTest.QTouchEventSequence.release(int touchId, QPoint pt, QWidget widget)'''
            return QTest.QTouchEventSequence()
        def move(self, touchId, pt, window = None):
            '''QTest.QTouchEventSequence QTest.QTouchEventSequence.move(int touchId, QPoint pt, QWindow window = None)'''
            return QTest.QTouchEventSequence()
        def move(self, touchId, pt, widget):
            '''QTest.QTouchEventSequence QTest.QTouchEventSequence.move(int touchId, QPoint pt, QWidget widget)'''
            return QTest.QTouchEventSequence()
        def press(self, touchId, pt, window = None):
            '''QTest.QTouchEventSequence QTest.QTouchEventSequence.press(int touchId, QPoint pt, QWindow window = None)'''
            return QTest.QTouchEventSequence()
        def press(self, touchId, pt, widget):
            '''QTest.QTouchEventSequence QTest.QTouchEventSequence.press(int touchId, QPoint pt, QWidget widget)'''
            return QTest.QTouchEventSequence()





# AUTO-GENERATED FILE -- DO NOT EDIT

""" The functions in this module allow compression and decompression using the
zlib library, which is based on GNU zip.

adler32(string[, start]) -- Compute an Adler-32 checksum.
compress(string[, level]) -- Compress string, with compression level in 1-9.
compressobj([level]) -- Return a compressor object.
crc32(string[, start]) -- Compute a CRC-32 checksum.
decompress(string,[wbits],[bufsize]) -- Decompresses a compressed string.
decompressobj([wbits]) -- Return a decompressor object.

'wbits' is window buffer size.
Compressor objects support compress() and flush() methods; decompressor
objects support decompress() and flush(). """

DEFLATED = 8
DEF_MEM_LEVEL = 8
MAX_WBITS = 15
ZLIB_VERSION = '1.2.5'
Z_BEST_COMPRESSION = 9
Z_BEST_SPEED = 1
Z_DEFAULT_COMPRESSION = -1
Z_DEFAULT_STRATEGY = 0
Z_FILTERED = 1
Z_FINISH = 4
Z_FULL_FLUSH = 3
Z_HUFFMAN_ONLY = 2
Z_NO_FLUSH = 0
Z_SYNC_FLUSH = 2
__package__ = None
__version__ = '1.0'

def adler32(string, start=None):
  """ adler32(string[, start]) -- Compute an Adler-32 checksum of string.
  
  An optional starting value can be specified.  The returned checksum is
  a signed integer. """
  return ""

def compress(string, level=None):
  """ compress(string[, level]) -- Returned compressed string.
  
  Optional arg level is the compression level, in 1-9. """
  return ""

def compressobj(level=None):
  """ compressobj([level]) -- Return a compressor object.
  
  Optional arg level is the compression level, in 1-9. """
  return None

def crc32(string, start=None):
  """ crc32(string[, start]) -- Compute a CRC-32 checksum of string.
  
  An optional starting value can be specified.  The returned checksum is
  a signed integer. """
  return ""

def decompress(string, wbits=None, bufsize=None):
  """ decompress(string[, wbits[, bufsize]]) -- Return decompressed string.
  
  Optional arg wbits is the window buffer size.  Optional arg bufsize is
  the initial output buffer size. """
  return ""

def decompressobj(wbits=None):
  """ decompressobj([wbits]) -- Return a decompressor object.
  
  Optional arg wbits is the window buffer size. """
  return None

class error(Exception):

  pass




class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class DNSSD():
    """"""
    class ServiceModel(QAbstractItemModel):
        """"""
        # Enum DNSSD.ServiceModel.ModelColumns
        ServiceName = 0
        Host = 0
        Port = 0
    
        # Enum DNSSD.ServiceModel.AdditionalRoles
        ServicePtrRole = 0
    
        def __init__(self, browser, parent = None):
            '''void DNSSD.ServiceModel.__init__(DNSSD.ServiceBrowser browser, QObject parent = None)'''
        def hasIndex(self, row, column, parent):
            '''bool DNSSD.ServiceModel.hasIndex(int row, int column, QModelIndex parent)'''
            return bool()
        def headerData(self, section, orientation, role = None):
            '''QVariant DNSSD.ServiceModel.headerData(int section, Qt.Orientation orientation, int role = Qt.DisplayRole)'''
            return QVariant()
        def data(self, index, role = None):
            '''QVariant DNSSD.ServiceModel.data(QModelIndex index, int role = Qt.DisplayRole)'''
            return QVariant()
        def index(self, row, column, parent = QModelIndex()):
            '''QModelIndex DNSSD.ServiceModel.index(int row, int column, QModelIndex parent = QModelIndex())'''
            return QModelIndex()
        def parent(self, index):
            '''QModelIndex DNSSD.ServiceModel.parent(QModelIndex index)'''
            return QModelIndex()
        def rowCount(self, parent = QModelIndex()):
            '''int DNSSD.ServiceModel.rowCount(QModelIndex parent = QModelIndex())'''
            return int()
        def columnCount(self, parent = QModelIndex()):
            '''int DNSSD.ServiceModel.columnCount(QModelIndex parent = QModelIndex())'''
            return int()
    class RemoteService(QObject, DNSSD.ServiceBase):
        """"""
        def __init__(self, name, type, domain):
            '''void DNSSD.RemoteService.__init__(QString name, QString type, QString domain)'''
        def virtual_hook(self, id, data):
            '''void DNSSD.RemoteService.virtual_hook(int id, sip.voidptr data)'''
        resolved = pyqtSignal() # void resolved(bool) - signal
        def isResolved(self):
            '''bool DNSSD.RemoteService.isResolved()'''
            return bool()
        def resolve(self):
            '''bool DNSSD.RemoteService.resolve()'''
            return bool()
        def resolveAsync(self):
            '''void DNSSD.RemoteService.resolveAsync()'''
    class DomainBrowser(QObject):
        """"""
        # Enum DNSSD.DomainBrowser.DomainType
        Browsing = 0
        Publishing = 0
    
        def __init__(self, type, parent = None):
            '''void DNSSD.DomainBrowser.__init__(DNSSD.DomainBrowser.DomainType type, QObject parent = None)'''
        domainAdded = pyqtSignal() # void domainAdded(const QStringamp;) - signal
        domainRemoved = pyqtSignal() # void domainRemoved(const QStringamp;) - signal
        def isRunning(self):
            '''bool DNSSD.DomainBrowser.isRunning()'''
            return bool()
        def startBrowse(self):
            '''void DNSSD.DomainBrowser.startBrowse()'''
        def domains(self):
            '''QStringList DNSSD.DomainBrowser.domains()'''
            return QStringList()
    class DomainModel(QAbstractItemModel):
        """"""
        def __init__(self, browser, parent = None):
            '''void DNSSD.DomainModel.__init__(DNSSD.DomainBrowser browser, QObject parent = None)'''
        def hasIndex(self, row, column, parent):
            '''bool DNSSD.DomainModel.hasIndex(int row, int column, QModelIndex parent)'''
            return bool()
        def data(self, index, role = None):
            '''QVariant DNSSD.DomainModel.data(QModelIndex index, int role = Qt.DisplayRole)'''
            return QVariant()
        def index(self, row, column, parent = QModelIndex()):
            '''QModelIndex DNSSD.DomainModel.index(int row, int column, QModelIndex parent = QModelIndex())'''
            return QModelIndex()
        def parent(self, index):
            '''QModelIndex DNSSD.DomainModel.parent(QModelIndex index)'''
            return QModelIndex()
        def rowCount(self, parent = QModelIndex()):
            '''int DNSSD.DomainModel.rowCount(QModelIndex parent = QModelIndex())'''
            return int()
        def columnCount(self, parent = QModelIndex()):
            '''int DNSSD.DomainModel.columnCount(QModelIndex parent = QModelIndex())'''
            return int()
    class ServiceTypeBrowser(QObject):
        """"""
        def __init__(self, domain = QString(), parent = None):
            '''void DNSSD.ServiceTypeBrowser.__init__(QString domain = QString(), QObject parent = None)'''
        finished = pyqtSignal() # void finished() - signal
        serviceTypeAdded = pyqtSignal() # void serviceTypeAdded(const QStringamp;) - signal
        serviceTypeRemoved = pyqtSignal() # void serviceTypeRemoved(const QStringamp;) - signal
        def isRunning(self):
            '''bool DNSSD.ServiceTypeBrowser.isRunning()'''
            return bool()
        def startBrowse(self):
            '''void DNSSD.ServiceTypeBrowser.startBrowse()'''
        def serviceTypes(self):
            '''QStringList DNSSD.ServiceTypeBrowser.serviceTypes()'''
            return QStringList()
    class ServiceBrowser(QObject):
        """"""
        # Enum DNSSD.ServiceBrowser.State
        Working = 0
        Stopped = 0
        Unsupported = 0
    
        def __init__(self, type, autoResolve = False, domain = QString(), subtype = QString()):
            '''void DNSSD.ServiceBrowser.__init__(QString type, bool autoResolve = False, QString domain = QString(), QString subtype = QString())'''
        def virtual_hook(self):
            '''sip.voidptr DNSSD.ServiceBrowser.virtual_hook()'''
            return sip.voidptr()
        finished = pyqtSignal() # void finished() - signal
        serviceRemoved = pyqtSignal() # void serviceRemoved(DNSSD::RemoteService::Ptr) - signal
        serviceAdded = pyqtSignal() # void serviceAdded(DNSSD::RemoteService::Ptr) - signal
        def getLocalHostName(self):
            '''static QString DNSSD.ServiceBrowser.getLocalHostName()'''
            return QString()
        def resolveHostName(self, hostname):
            '''static QHostAddress DNSSD.ServiceBrowser.resolveHostName(QString hostname)'''
            return QHostAddress()
        def isAutoResolving(self):
            '''bool DNSSD.ServiceBrowser.isAutoResolving()'''
            return bool()
        def isAvailable(self):
            '''static DNSSD.ServiceBrowser.State DNSSD.ServiceBrowser.isAvailable()'''
            return DNSSD.ServiceBrowser.State()
        def startBrowse(self):
            '''void DNSSD.ServiceBrowser.startBrowse()'''
        def services(self):
            '''unknown-type DNSSD.ServiceBrowser.services()'''
            return unknown-type()
    class PublicService(QObject, DNSSD.ServiceBase):
        """"""
        def __init__(self, name = QString(), type = QString(), port = 0, domain = QString(), subtypes = QStringList()):
            '''void DNSSD.PublicService.__init__(QString name = QString(), QString type = QString(), int port = 0, QString domain = QString(), QStringList subtypes = QStringList())'''
        def virtual_hook(self):
            '''sip.voidptr DNSSD.PublicService.virtual_hook()'''
            return sip.voidptr()
        published = pyqtSignal() # void published(bool) - signal
        def subtypes(self):
            '''QStringList DNSSD.PublicService.subtypes()'''
            return QStringList()
        def setDomain(self, domain):
            '''void DNSSD.PublicService.setDomain(QString domain)'''
        def setPort(self, port):
            '''void DNSSD.PublicService.setPort(int port)'''
        def setSubTypes(self, subtypes):
            '''void DNSSD.PublicService.setSubTypes(QStringList subtypes)'''
        def setType(self, type):
            '''void DNSSD.PublicService.setType(QString type)'''
        def setServiceName(self, serviceName):
            '''void DNSSD.PublicService.setServiceName(QString serviceName)'''
        def setTextData(self, textData):
            '''void DNSSD.PublicService.setTextData(dict-of-QString-QByteArray textData)'''
        def publishAsync(self):
            '''void DNSSD.PublicService.publishAsync()'''
        def isPublished(self):
            '''bool DNSSD.PublicService.isPublished()'''
            return bool()
        def publish(self):
            '''bool DNSSD.PublicService.publish()'''
            return bool()
        def stop(self):
            '''void DNSSD.PublicService.stop()'''
    class ServiceBase(KShared):
        """"""
        def __init__(self, name = QString(), type = QString(), domain = QString(), host = QString(), port = 0):
            '''void DNSSD.ServiceBase.__init__(QString name = QString(), QString type = QString(), QString domain = QString(), QString host = QString(), int port = 0)'''
        def __ne__(self, o):
            '''bool DNSSD.ServiceBase.__ne__(DNSSD.ServiceBase o)'''
            return bool()
        def __eq__(self, o):
            '''bool DNSSD.ServiceBase.__eq__(DNSSD.ServiceBase o)'''
            return bool()
        def textData(self):
            '''dict-of-QString-QByteArray DNSSD.ServiceBase.textData()'''
            return dict-of-QString-QByteArray()
        def port(self):
            '''int DNSSD.ServiceBase.port()'''
            return int()
        def hostName(self):
            '''QString DNSSD.ServiceBase.hostName()'''
            return QString()
        def domain(self):
            '''QString DNSSD.ServiceBase.domain()'''
            return QString()
        def type(self):
            '''QString DNSSD.ServiceBase.type()'''
            return QString()
        def serviceName(self):
            '''QString DNSSD.ServiceBase.serviceName()'''
            return QString()


